@@ -4,7 +4,7 @@
  using a Metropolis-Hastings Monte Carlo algorithm                            
  -------------------------------------------------------                        
  D A T A   R O U T I N E S 
-
+ 
  creates data structures,
  read data (Electrophoretic loci, sequences, microsats),
  feeds data into tree (?),
@@ -15,9 +15,9 @@
  beerli@genetics.washington.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
-
+ 
 $Id: data.c,v 1.37 2001/09/07 23:56:13 beerli Exp $
-
+ 
 -------------------------------------------------------*/
 #include <string.h>
 
@@ -33,7 +33,7 @@ void create_data (data_fmt ** data);
 void get_data (FILE * infile, data_fmt * data, option_fmt * options);
 void print_data (world_fmt * world, option_fmt * options, data_fmt * data);
 void print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
-			 data_fmt * data);
+                         data_fmt * data);
 void free_datapart (data_fmt * data, option_fmt * options, long locus);
 /*private functions */
 void init_data_structure1 (data_fmt ** data, option_fmt * options);
@@ -43,36 +43,36 @@ void init_data_structure2 (data_fmt ** data, option_fmt * options, long pop);
 void init_data_structure3 (data_fmt * data);
 void read_popheader (FILE * infile, data_fmt * data, long pop);
 void read_indname (FILE * file, data_fmt * data, long pop, long ind,
-		   long nmlength);
+                   long nmlength);
 void read_popdata (FILE * file, data_fmt * data, long pop,
-		   option_fmt * options);
+                   option_fmt * options);
 void read_microalleles (FILE * infile, data_fmt * data, long pop, long ind);
 void read_alleles (FILE * infile, data_fmt * data, long pop, long ind);
 long read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
-		   long locus, long pop, long ind, long baseread);
+                   long locus, long pop, long ind, long baseread);
 void read_distance_fromfile (FILE * dfile, long tips, long nmlength,
-			     double **m);
+                             double **m);
 void finish_read_seq (FILE * infile, data_fmt * data, option_fmt * options,
-		      long pop, long baseread);
+                      long pop, long baseread);
 void print_alleledata (world_fmt * world, data_fmt * data,
-		       option_fmt * options);
+                       option_fmt * options);
 void print_seqdata (world_fmt * world, option_fmt * options, data_fmt * data);
 
 void print_header (FILE * outfile, long pop, world_fmt * world,
-		   option_fmt * options, data_fmt * data);
+                   option_fmt * options, data_fmt * data);
 void create_alleles (data_fmt * data);
 void addAllele (data_fmt * data, char s[], long locus, long *z);
 void set_numind (data_fmt * data);
 void print_seq_pop (long locus, long pop, world_fmt * world,
-		    option_fmt * options, data_fmt * data);
+                    option_fmt * options, data_fmt * data);
 void print_seq_ind (long locus, long pop, long ind, world_fmt * world,
-		    option_fmt * options, data_fmt * data);
+                    option_fmt * options, data_fmt * data);
 void print_locus_head (long locus, world_fmt * world, option_fmt * options,
-		       data_fmt * data);
+                       data_fmt * data);
 void find_delimiter (char *title, char *dlm);
 void read_geofile (data_fmt * data, option_fmt * options, long numpop);
-void read_uep_fromfile (FILE * uepfile, long tips, long nmlength, long **uep,
-			long *uepsites, long datatype);
+void read_uep_fromfile (FILE * uepfile, long tips, long nmlength, int **uep,
+                        long *uepsites, long datatype);
 void read_uepfile (data_fmt * data, option_fmt * options, long numpop);
 
 
@@ -87,15 +87,15 @@ create_data (data_fmt ** data)
 void
 init_data (data_fmt * data)
 {
-
+ 
 }
-
+ 
 void
 destroy_data (data_fmt * data)
 {
   free (data);
 }
-
+ 
 */
 
 void
@@ -131,16 +131,18 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options)
     {
       read_popheader (data->infile, data, pop);
       if (options->progress)
-	fprintf (stdout, "Reading %s ...\n", data->popnames[pop]);
+        fprintf (stdout, "Reading %s ...\n", data->popnames[pop]);
       if (options->writelog)
-	fprintf (options->logfile, "Reading %s ...\n", data->popnames[pop]);
+        fprintf (options->logfile, "Reading %s ...\n", data->popnames[pop]);
       init_data_structure2 (&data, options, pop);
       read_popdata (data->infile, data, pop, options);
     }
   read_geofile (data, options, data->numpop);
 #ifdef UEP
+
   read_uepfile (data, options, data->numpop);
 #endif
+
   if (options->progress)
     fprintf (stdout, "\n\n");
   init_data_structure3 (data);
@@ -155,7 +157,7 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options)
     case 'm':
       create_alleles (data);
       for (pop = 0; pop < data->loci; pop++)
-	data->maxalleles[pop] = options->micro_stepnum;
+        data->maxalleles[pop] = options->micro_stepnum;
       break;
     }
 }
@@ -169,22 +171,22 @@ init_data_structure1 (data_fmt ** data, option_fmt * options)
   if ((*data)->yy == NULL)
     {
       (*data)->yy =
-	(char *****) malloc (sizeof (char ****) * (*data)->numpop);
+        (char *****) malloc (sizeof (char ****) * (*data)->numpop);
       (*data)->seq = (seqmodel_fmt *) calloc (1, sizeof (seqmodel_fmt));
       (*data)->popnames =
-	(char **) malloc (sizeof (char *) * (*data)->numpop);
+        (char **) malloc (sizeof (char *) * (*data)->numpop);
       (*data)->indnames =
-	(char ***) malloc (sizeof (char **) * (*data)->numpop);
+        (char ***) malloc (sizeof (char **) * (*data)->numpop);
       (*data)->numind = (long **) malloc (sizeof (long *) * (*data)->numpop);
       for (pop = 0; pop < (*data)->numpop; pop++)
-	{
-	  (*data)->popnames[pop] =
-	    (char *) calloc (1, sizeof (char) * LINESIZE);
-	  (*data)->numind[pop] =
-	    (long *) malloc (sizeof (long) * (*data)->loci);
-	}
+        {
+          (*data)->popnames[pop] =
+            (char *) calloc (1, sizeof (char) * LINESIZE);
+          (*data)->numind[pop] =
+            (long *) malloc (sizeof (long) * (*data)->loci);
+        }
       (*data)->seq->sites =
-	(long *) calloc (1, sizeof (long) * (*data)->loci);
+        (long *) calloc (1, sizeof (long) * (*data)->loci);
     }
   else
     {
@@ -205,29 +207,29 @@ init_data_structure2 (data_fmt ** data, option_fmt * options, long pop)
   for (ind = 0; ind < indalloc; ind++)
     {
       (*data)->indnames[pop][ind] =
-	(char *) calloc (1, sizeof (char) * (1 + options->nmlength));
+        (char *) calloc (1, sizeof (char) * (1 + options->nmlength));
       (*data)->yy[pop][ind] =
-	(char ***) malloc (sizeof (char **) * (*data)->loci);
+        (char ***) malloc (sizeof (char **) * (*data)->loci);
       for (locus = 0; locus < (*data)->loci; locus++)
-	{
-	  if (!strchr (SEQUENCETYPES, options->datatype))
-	    {
-	      (*data)->yy[pop][ind][locus] =
-		(char **) calloc (1, sizeof (char *) * 2);
-	      (*data)->yy[pop][ind][locus][0] =
-		(char *) calloc (1, sizeof (char) * options->allelenmlength);
-	      (*data)->yy[pop][ind][locus][1] =
-		(char *) calloc (1, sizeof (char) * options->allelenmlength);
-	    }
-	  else
-	    {
-	      (*data)->yy[pop][ind][locus] =
-		(char **) calloc (1, sizeof (char *));
-	      (*data)->yy[pop][ind][locus][0] =
-		(char *) calloc (1,
-				 sizeof (char) * (*data)->seq->sites[locus]);
-	    }
-	}
+        {
+          if (!strchr (SEQUENCETYPES, options->datatype))
+            {
+              (*data)->yy[pop][ind][locus] =
+                (char **) calloc (1, sizeof (char *) * 2);
+              (*data)->yy[pop][ind][locus][0] =
+                (char *) calloc (1, sizeof (char) * (options->allelenmlength+1));
+              (*data)->yy[pop][ind][locus][1] =
+                (char *) calloc (1, sizeof (char) * (options->allelenmlength+1));
+            }
+          else
+            {
+              (*data)->yy[pop][ind][locus] =
+                (char **) calloc (1, sizeof (char *));
+              (*data)->yy[pop][ind][locus][0] =
+                (char *) calloc (1,
+                                 sizeof (char) * ((*data)->seq->sites[locus]+1));
+            }
+        }
     }
 }
 
@@ -240,19 +242,19 @@ free_datapart (data_fmt * data, option_fmt * options, long locus)
   for (pop = 0; pop < data->numpop; pop++)
     {
       for (ind = 0; ind < data->numind[pop][locus] / genomes; ind++)
-	{
-	  if (strchr (SEQUENCETYPES, options->datatype))
-	    {
-	      free (data->yy[pop][ind][locus][0]);
-	      free (data->yy[pop][ind][locus][1]);
-	      free (data->yy[pop][ind][locus]);
-	    }
-	  else
-	    {
-	      free (data->yy[pop][ind][locus][0]);
-	      free (data->yy[pop][ind][locus]);
-	    }
-	}
+        {
+          if (strchr (SEQUENCETYPES, options->datatype))
+            {
+              free (data->yy[pop][ind][locus][0]);
+              free (data->yy[pop][ind][locus][1]);
+              free (data->yy[pop][ind][locus]);
+            }
+          else
+            {
+              free (data->yy[pop][ind][locus][0]);
+              free (data->yy[pop][ind][locus]);
+            }
+        }
     }
 }
 
@@ -267,9 +269,9 @@ init_data_structure3 (data_fmt * data)
     {
       maxi = 0;
       for (pop = 0; pop < data->numpop; pop++)
-	maxi += data->numind[pop][FLOC] * 2;
+        maxi += data->numind[pop][FLOC] * 2;
       data->allele[locus] =
-	(allele_fmt *) calloc (1, sizeof (allele_fmt) * maxi);
+        (allele_fmt *) calloc (1, sizeof (allele_fmt) * maxi);
     }
   data->maxalleles = (long *) calloc (1, sizeof (long) * data->loci);
   data->skiploci =
@@ -288,50 +290,50 @@ read_header (FILE * infile, data_fmt * data, option_fmt * options)
     {
     case 'a':
       sscanf (input, "%1s%ld%ld%[^\n]", &options->datatype, &(data->numpop),
-	      &(data->loci), options->title);
+              &(data->loci), options->title);
       find_delimiter (options->title, &data->dlm);
       break;
     case 'b':
     case 'm':
       sscanf (input, "%1s%ld%ld%1s%[^\n]", &options->datatype,
-	      &(data->numpop), &(data->loci), &data->dlm, options->title);
+              &(data->numpop), &(data->loci), &data->dlm, options->title);
       break;
     case 's':
     case 'n':
     case 'u':
     case 'f':
       sscanf (input, "%1s%ld%ld%[^\n]", &options->datatype, &(data->numpop),
-	      &(data->loci), options->title);
+              &(data->loci), options->title);
       break;
     case 'g':			/* fall through if a menu change forces to analyze data
-				   instead of using the already sampled genealogies */
+      				   instead of using the already sampled genealogies */
       if (options->datatype == 'g')
-	break;
+        break;
       else
-	memmove (input, input + 1, (strlen (input) - 1) * sizeof (char));
+        memmove (input, input + 1, (strlen (input) - 1) * sizeof (char));
     default:
       switch (options->datatype)
-	{
-	case 'a':
-	  sscanf (input, "%ld%ld%[^\n]", &(data->numpop), &(data->loci),
-		  options->title);
-	  find_delimiter (options->title, &data->dlm);
-	  break;
-	case 'b':
-	case 'm':
-	  sscanf (input, "%ld%ld%1s%[^\n]", &(data->numpop), &(data->loci),
-		  &(data->dlm), options->title);
-	  break;
-	case 's':
-	case 'n':
-	case 'u':
-	case 'f':
-	  sscanf (input, "%ld%ld%[^\n]", &(data->numpop), &(data->loci),
-		  options->title);
-	  break;
-	default:
-	  usererror ("Datatype is wrong, please use a valid data type!");
-	}
+        {
+        case 'a':
+          sscanf (input, "%ld%ld%[^\n]", &(data->numpop), &(data->loci),
+                  options->title);
+          find_delimiter (options->title, &data->dlm);
+          break;
+        case 'b':
+        case 'm':
+          sscanf (input, "%ld%ld%1s%[^\n]", &(data->numpop), &(data->loci),
+                  &(data->dlm), options->title);
+          break;
+        case 's':
+        case 'n':
+        case 'u':
+        case 'f':
+          sscanf (input, "%ld%ld%[^\n]", &(data->numpop), &(data->loci),
+                  options->title);
+          break;
+        default:
+          usererror ("Datatype is wrong, please use a valid data type!");
+        }
     }
   options->datatype = lowercase (options->datatype);
 }
@@ -353,10 +355,10 @@ find_delimiter (char *title, char *dlm)
       *dlm = *p;
       p++;
       while (*p == ' ')
-	{
-	  p++;
-	  z++;
-	}
+        {
+          p++;
+          z++;
+        }
       memmove (title, p, sizeof (char) * (strlen (title) - z));
     }
 }
@@ -375,19 +377,19 @@ read_sites (data_fmt * data)
   for (locus = 0; locus < data->loci; locus++)
     {
       while (isspace ((int) *p))
-	p++;
+        p++;
       if (locus == 0)
-	a = strtok (p, " ");
+        a = strtok (p, " ");
       else
-	a = strtok (NULL, " ");
+        a = strtok (NULL, " ");
       data->seq->sites[locus] = atoi (a);
       if (data->seq->sites[locus] == 0)
-	{
-	  warning ("This does look like sequence data\n");
-	  warning ("I just read a number of sites=0\n");
-	  warning ("If you use the wrong data type, the program\n");
-	  usererror ("will crash anyway, so I stop now\n");
-	}
+        {
+          warning ("This does look like sequence data\n");
+          warning ("I just read a number of sites=0\n");
+          warning ("If you use the wrong data type, the program\n");
+          usererror ("will crash anyway, so I stop now\n");
+        }
     }
   free (input);
 
@@ -401,7 +403,7 @@ read_popheader (FILE * infile, data_fmt * data, long pop)
   if ((p = (char *) strpbrk (input, CRLF)) != NULL)
     *p = '\0';
   sscanf (input, "%ld%[^\n]", &(data->numind[pop][FLOC]),
-	  data->popnames[pop]);
+          data->popnames[pop]);
   translate (data->popnames[pop], ' ', '_');
   translate (data->popnames[pop], '\t', '_');
   if (data->numind[pop][FLOC] == 0)
@@ -412,8 +414,13 @@ void
 read_indname (FILE * file, data_fmt * data, long pop, long ind, long nmlength)
 {
   long i = 0;
+  char ch;
   while (i < nmlength)
-    data->indnames[pop][ind][i++] = getc (file);
+    {
+      ch = getc (file);
+      if(!strchr("\r\n",ch))
+        data->indnames[pop][ind][i++] = ch;
+    }
   data->indnames[pop][ind][nmlength] = '\0';
 }
 
@@ -426,26 +433,26 @@ read_popdata (FILE * infile, data_fmt * data, long pop, option_fmt * options)
     {
       read_indname (infile, data, pop, ind, options->nmlength);
       switch (options->datatype)
-	{
-	case 'a':
-	case 'b':
-	case 'm':
-	  if (data->dlm == '\0')
-	    read_alleles (infile, data, pop, ind);
-	  else
-	    read_microalleles (infile, data, pop, ind);
-	  break;
-	case 's':
-	case 'n':
-	case 'u':
-	case 'f':
-	  baseread = read_ind_seq (infile, data, options, locus, pop, ind, 0);
-	  break;
-	default:
-	  usererror
-	    ("Wrong datatype, only the types a, m, s, n\n       (electrophoretic alleles, \n       microsatellite data,\n       sequence data,\n       SNP polymorphism)\n        are allowed.\n");
-	  break;
-	}
+        {
+        case 'a':
+        case 'b':
+        case 'm':
+          if (data->dlm == '\0')
+            read_alleles (infile, data, pop, ind);
+          else
+            read_microalleles (infile, data, pop, ind);
+          break;
+        case 's':
+        case 'n':
+        case 'u':
+        case 'f':
+          baseread = read_ind_seq (infile, data, options, locus, pop, ind, 0);
+          break;
+        default:
+          usererror
+          ("Wrong datatype, only the types a, m, s, n\n       (electrophoretic alleles, \n       microsatellite data,\n       sequence data,\n       SNP polymorphism)\n        are allowed.\n");
+          break;
+        }
     }
   if (!strchr (SEQUENCETYPES, options->datatype))
     return;
@@ -473,37 +480,37 @@ read_microalleles (FILE * infile, data_fmt * data, long pop, long ind)
   for (locus = 0; locus < data->loci; locus++)
     {
       while (isspace ((int) *input))
-	input++;
+        input++;
       if (input[0] == '\0')
-	FGETS (input, LONGLINESIZE, infile);
+        FGETS (input, LONGLINESIZE, infile);
       i = 0;
       while (input[i] != ' ' && input[i] != dlm[0])
-	{
-	  a1[i] = input[i];
-	  i++;
-	}
+        {
+          a1[i] = input[i];
+          i++;
+        }
       a1[i] = '\0';
       input += i;
       i = 0;
       if (input[i] == dlm[0])
-	{
-	  input++;
-	  while (input[i] != ' ' && input[i] != '\0')
-	    {
-	      a2[i] = input[i];
-	      i++;
-	    }
-	  a2[i] = '\0';
-	  if (a2[0] == '\0')
-	    {
-	      strcpy (a2, a1);
-	    }
-	  input += i;
-	}
+        {
+          input++;
+          while (input[i] != ' ' && input[i] != '\0')
+            {
+              a2[i] = input[i];
+              i++;
+            }
+          a2[i] = '\0';
+          if (a2[0] == '\0')
+            {
+              strcpy (a2, a1);
+            }
+          input += i;
+        }
       else
-	{
-	  strcpy (a2, a1);
-	}
+        {
+          strcpy (a2, a1);
+        }
       strcpy (data->yy[pop][ind][locus][0], a1);
       strcpy (data->yy[pop][ind][locus][1], a2);
     }
@@ -528,26 +535,26 @@ read_alleles (FILE * infile, data_fmt * data, long pop, long ind)
   for (locus = 0; locus < data->loci; locus++)
     {
       while (isspace ((int) *input))
-	{
-	  input++;
-	}
+        {
+          input++;
+        }
       if (sscanf (input, "%s", a) == 1)
-	{
-	  input += strlen (a);
-	}
+        {
+          input += strlen (a);
+        }
 
       data->yy[pop][ind][locus][0][0] = a[0];
       data->yy[pop][ind][locus][0][1] = '\0';
       if (a[1] == '\0')
-	{
-	  data->yy[pop][ind][locus][1][0] = a[0];
-	  data->yy[pop][ind][locus][1][1] = '\0';
-	}
+        {
+          data->yy[pop][ind][locus][1][0] = a[0];
+          data->yy[pop][ind][locus][1][1] = '\0';
+        }
       else
-	{
-	  data->yy[pop][ind][locus][1][0] = a[1];
-	  data->yy[pop][ind][locus][1][1] = '\0';
-	}
+        {
+          data->yy[pop][ind][locus][1][0] = a[1];
+          data->yy[pop][ind][locus][1][1] = '\0';
+        }
     }
   free (a);
   free (isave);
@@ -555,7 +562,7 @@ read_alleles (FILE * infile, data_fmt * data, long pop, long ind)
 
 long
 read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
-	      long locus, long pop, long ind, long baseread)
+              long locus, long pop, long ind, long baseread)
 {
   long j;
   char charstate;
@@ -563,39 +570,49 @@ read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
   charstate = getc (infile);
   ungetc ((int) charstate, infile);
   while (j < data->seq->sites[locus]
-	 && !(options->interleaved && charstate == '\n'))
+         && !(options->interleaved && strchr(CRLF,charstate)))
     {
       charstate = getc (infile);
-      if (charstate == '\n')
-	{
-	  if (options->interleaved)
-	    return j;
-	  else
-	    charstate = ' ';
-	}
-      if (charstate == '\r' || charstate == ' '
-	  || (charstate >= '0' && charstate <= '9') || charstate == '\\')
-	continue;
+      if (strchr(CRLF,charstate))
+        {
+          if (options->interleaved)
+            {
+              while(strchr(CRLF,charstate=getc(infile)))
+                ;
+              ungetc ((int) charstate, infile);
+              return j;
+            }
+          else
+            charstate = ' ';
+        }
+      if (charstate == ' '
+          || (charstate >= '0' && charstate <= '9') || charstate == '\\')
+        continue;
       charstate = uppercase (charstate);
       //      printf("%c",charstate);
       if ((strchr ("ABCDGHKMNRSTUVWXY?O-", (int) charstate)) == NULL)
-	{
-	  printf
-	    ("ERROR: BAD BASE: %c AT POSITION %5ld OF INDIVIDUUM %3li in POPULATION %ld\n",
-	     charstate, j, ind, pop);
-	  printf
-	    ("Last complete sequences was in population %li, individual %li and locus %li:\n%s",
-	     pop + 1, ind - 1, locus, data->indnames[pop][ind - 1]);
-	  for (j = 0; j < data->seq->sites[locus]; j++)
-	    printf ("%c", data->yy[pop][ind - 1][locus][0][j]);
-	  exit (EXIT_FAILURE);
-	}
+        {
+          printf
+          ("ERROR: BAD BASE: %c AT POSITION %5ld OF INDIVIDUUM %3li in POPULATION %ld\n",
+           charstate, j, ind, pop);
+          printf
+          ("Last complete sequences was in population %li, individual %li and locus %li:\n%s",
+           pop + 1, ind - 1, locus, data->indnames[pop][ind - 1]);
+          for (j = 0; j < data->seq->sites[locus]; j++)
+            printf ("%c", data->yy[pop][ind - 1][locus][0][j]);
+          exit (EXIT_FAILURE);
+        }
       data->yy[pop][ind][locus][0][j++] = charstate;
     }
   charstate = getc (infile);	/* swallow the \n or \r */
 #ifndef MAC
+
   if (charstate == '\r')
-    charstate = getc (infile);	/* swallow the \n */
+    {
+      charstate = getc (infile);	/* swallow the \n */
+      if(charstate!='\n')
+        ungetc((int) charstate, infile);
+    }
 #endif
   return j;
 }
@@ -612,26 +629,26 @@ read_distance_fromfile (FILE * dfile, long tips, long nmlength, double **m)
       // and that all n x n cells are filled.
       FGETS (input, LINESIZE, dfile);	//reads header line with
       for (i = 0; i < tips; i++)	// of individuals
-	{
-	  //reads header line with
-	  FGETS (input, nmlength + 1, dfile);
-	  for (j = 0; j < tips; j++)
-	    {
-	      fscanf (dfile, "%lf", &m[i][j]);
-	    }
-	  // reads the last \n from the
-	  // data matrix
-	  FGETS (input, LINESIZE, dfile);
-	}
+        {
+          //reads header line with
+          FGETS (input, nmlength + 1, dfile);
+          for (j = 0; j < tips; j++)
+            {
+              fscanf (dfile, "%lf", &m[i][j]);
+            }
+          // reads the last \n from the
+          // data matrix
+          FGETS (input, LINESIZE, dfile);
+        }
     }
 }
 
 #ifdef UEP
-// uep function 
+// uep function
 
 void
-read_uep_fromfile (FILE * uepfile, long tips, long nmlength, long **uep,
-		   long *uepsites, long datatype)
+read_uep_fromfile (FILE * uepfile, long tips, long nmlength, int **uep,
+                   long *uepsites, long datatype)
 {
   char input[LINESIZE];
   long i, j;
@@ -644,85 +661,85 @@ read_uep_fromfile (FILE * uepfile, long tips, long nmlength, long **uep,
       // of individuals and uep sites
       sscanf (input, "%li%li", &thistips, uepsites);
       if (thistips != tips)
-	error ("UEP datafile and infile are inconsistent!");
+        error ("UEP datafile and infile are inconsistent!");
       if (strchr (SEQUENCETYPES, datatype))
-	{
-	  for (i = 0; i < tips; i++)
-	    {
-	      uep[i] = (long *) calloc (*uepsites, sizeof (long));
-	      FGETS (input, nmlength + 1, uepfile);	//reads each line
-	      for (j = 0; j < *uepsites; ++j)
-		fscanf (uepfile, "%li", &uep[i][j]);
-	      // reads the last \n from the data matrix
-	      FGETS (input, LINESIZE, uepfile);
-	    }
-	}
+        {
+          for (i = 0; i < tips; i++)
+            {
+              uep[i] = (int *) calloc (*uepsites, sizeof (int));
+              FGETS (input, nmlength + 1, uepfile);	//reads each line
+              for (j = 0; j < *uepsites; ++j)
+                fscanf (uepfile, "%i", &uep[i][j]);
+              // reads the last \n from the data matrix
+              FGETS (input, LINESIZE, uepfile);
+            }
+        }
       else
-	{
-	  for (i = 0; i < tips; i++)
-	    {
-	      uep[i] = (long *) calloc (*uepsites, sizeof (long));
-	      uep[i + tips] = (long *) calloc (*uepsites, sizeof (long));
-	      FGETS (input, nmlength + 1, uepfile);	//reads each line
-	      for (j = 0; j < *uepsites; ++j)
-		fscanf (uepfile, "%li", &uep[i][j]);
-	      // finished reading first allele, no onto the second
-	      for (j = 0; j < *uepsites; ++j)
-		fscanf (uepfile, "%li", &uep[i + tips][j]);
-	      // reads the last \n from the data matrix
-	      FGETS (input, LINESIZE, uepfile);
-	    }
-	}
+        {
+          for (i = 0; i < tips; i++)
+            {
+              uep[i] = (int *) calloc (*uepsites, sizeof (int));
+              uep[i + tips] = (int *) calloc (*uepsites, sizeof (int));
+              FGETS (input, nmlength + 1, uepfile);	//reads each line
+              for (j = 0; j < *uepsites; ++j)
+                fscanf (uepfile, "%i", &uep[i][j]);
+              // finished reading first allele, no onto the second
+              for (j = 0; j < *uepsites; ++j)
+                fscanf (uepfile, "%i", &uep[i + tips][j]);
+              // reads the last \n from the data matrix
+              FGETS (input, LINESIZE, uepfile);
+            }
+        }
     }
 }
 #endif
 
 void
 finish_read_seq (FILE * infile, data_fmt * data, option_fmt * options,
-		 long pop, long baseread)
+                 long pop, long baseread)
 {
 
   long ind, baseread2 = 0, locus = 0;
   if (options->interleaved)
     {
       while (baseread < data->seq->sites[0])
-	{
-	  for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
-	    {
-	      baseread2 =
-		read_ind_seq (infile, data, options, locus, pop, ind,
-			      baseread);
-	    }
-	  baseread = baseread2;
-	}
+        {
+          for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+            {
+              baseread2 =
+                read_ind_seq (infile, data, options, locus, pop, ind,
+                              baseread);
+            }
+          baseread = baseread2;
+        }
     }
   for (locus = 1; locus < data->loci; locus++)
     {
       baseread = 0;
       for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
-	{
-	  read_indname (infile, data, pop, ind, options->nmlength);
-	  baseread = read_ind_seq (infile, data, options, locus, pop, ind, 0);
-	}
+        {
+          read_indname (infile, data, pop, ind, options->nmlength);
+          baseread = read_ind_seq (infile, data, options, locus, pop, ind, 0);
+        }
       if (options->interleaved)
-	{
-	  while (baseread < data->seq->sites[locus])
-	    {
-	      for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
-		{
-		  baseread2 =
-		    read_ind_seq (infile, data, options, locus, pop, ind,
-				  baseread);
-		}
-	      baseread = baseread2;
-	    }
-	}
+        {
+          while (baseread < data->seq->sites[locus])
+            {
+              for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+                {
+                  baseread2 =
+                    read_ind_seq (infile, data, options, locus, pop, ind,
+                                  baseread);
+                }
+              baseread = baseread2;
+            }
+        }
     }
 }
 
 void
 print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
-		    data_fmt * data)
+                    data_fmt * data)
 {
   long total = 0;
   long pop;
@@ -753,21 +770,21 @@ print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
     }
   fprintf (file, "Datatype:                                %20s\n", dstring);
   fprintf (file, "Number of loci:                          %20li\n\n",
-	   data->loci);
+           data->loci);
 
   fprintf (file,
-	   "Population                                        Individuals\n");
+           "Population                                        Individuals\n");
   fprintf (file,
-	   "-------------------------------------------------------------\n");
+           "-------------------------------------------------------------\n");
   for (pop = 0; pop < world->numpop; pop++)
     {
       fprintf (file, "%3li %-50.50s %6li\n", pop + 1, data->popnames[pop],
-	       data->numind[pop][FLOC]);
+               data->numind[pop][FLOC]);
       total += data->numind[pop][FLOC];
     }
   fprintf (file,
-	   "Total of all populations                               %6li\n\n",
-	   total);
+           "Total of all populations                               %6li\n\n",
+           total);
   fflush (file);
 }
 
@@ -777,19 +794,19 @@ print_data (world_fmt * world, option_fmt * options, data_fmt * data)
   if (options->printdata)
     {
       switch (options->datatype)
-	{
-	case 'a':
-	case 'b':
-	case 'm':
-	  print_alleledata (world, data, options);
-	  break;
-	case 's':
-	case 'n':
-	case 'u':
-	case 'f':
-	  print_seqdata (world, options, data);
-	  break;
-	}
+        {
+        case 'a':
+        case 'b':
+        case 'm':
+          print_alleledata (world, data, options);
+          break;
+        case 's':
+        case 'n':
+        case 'u':
+        case 'f':
+          print_seqdata (world, options, data);
+          break;
+        }
     }
 }
 
@@ -801,28 +818,28 @@ print_alleledata (world_fmt * world, data_fmt * data, option_fmt * options)
     {
       print_header (world->outfile, pop, world, options, data);
       for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
-	{
-	  fprintf (world->outfile, "%-*.*s ", (int) options->nmlength,
-		   (int) options->nmlength, data->indnames[pop][ind]);
-	  mult80 = options->nmlength;
-	  for (locus = 0; locus < data->loci; locus++)
-	    {
-	      mult80 +=
-		1 + strlen (data->yy[pop][ind][locus][0]) +
-		strlen (data->yy[pop][ind][locus][1]);
-	      if (mult80 >= 80)
-		{
-		  mult80 = 0;
-		  fprintf (world->outfile, "\n");
-		  for (i = 0; i < options->nmlength; i++)
-		    fputc (' ', world->outfile);
-		}
-	      fprintf (world->outfile, " %s.%-s",
-		       data->yy[pop][ind][locus][0],
-		       data->yy[pop][ind][locus][1]);
-	    }
-	  fprintf (world->outfile, "\n");
-	}
+        {
+          fprintf (world->outfile, "%-*.*s ", (int) options->nmlength,
+                   (int) options->nmlength, data->indnames[pop][ind]);
+          mult80 = options->nmlength;
+          for (locus = 0; locus < data->loci; locus++)
+            {
+              mult80 +=
+                1 + strlen (data->yy[pop][ind][locus][0]) +
+                strlen (data->yy[pop][ind][locus][1]);
+              if (mult80 >= 80)
+                {
+                  mult80 = 0;
+                  fprintf (world->outfile, "\n");
+                  for (i = 0; i < options->nmlength; i++)
+                    fputc (' ', world->outfile);
+                }
+              fprintf (world->outfile, " %s.%-s",
+                       data->yy[pop][ind][locus][0],
+                       data->yy[pop][ind][locus][1]);
+            }
+          fprintf (world->outfile, "\n");
+        }
       fprintf (world->outfile, "\n");
     }
   fprintf (world->outfile, "\n\n");
@@ -837,17 +854,17 @@ print_seqdata (world_fmt * world, option_fmt * options, data_fmt * data)
     {
       print_header (world->outfile, pop, world, options, data);
       for (locus = 0; locus < data->loci; locus++)
-	{
-	  print_locus_head (locus, world, options, data);
-	  print_seq_pop (locus, pop, world, options, data);
-	}
+        {
+          print_locus_head (locus, world, options, data);
+          print_seq_pop (locus, pop, world, options, data);
+        }
     }
   fflush (world->outfile);
 }
 
 void
 print_header (FILE * outfile, long pop, world_fmt * world,
-	      option_fmt * options, data_fmt * data)
+              option_fmt * options, data_fmt * data)
 {
   long i;
   long locus, mult80 = 80;
@@ -860,20 +877,20 @@ print_header (FILE * outfile, long pop, world_fmt * world,
     {
       fprintf (outfile, "%-s  ", (data->loci == 1 ? "locus" : "loci "));
       for (i = 0; i < (options->nmlength - 6); i++)
-	fputc (' ', outfile);
+        fputc (' ', outfile);
       for (locus = 0; locus < data->loci; locus++)
-	{
-	  if (locus * 4 + options->nmlength > mult80)
-	    {
-	      mult80 += 80;
-	      fprintf (outfile, "\n");
-	      for (i = 0; i < options->nmlength; i++)
-		fputc (' ', outfile);
-	    }
-	  fprintf (outfile, "  %2li", locus + 1);
-	}
+        {
+          if (locus * 4 + options->nmlength > mult80)
+            {
+              mult80 += 80;
+              fprintf (outfile, "\n");
+              for (i = 0; i < options->nmlength; i++)
+                fputc (' ', outfile);
+            }
+          fprintf (outfile, "  %2li", locus + 1);
+        }
       fprintf (outfile, "\n%-s\n",
-	       strncpy (input, "indiv.", options->nmlength));
+               strncpy (input, "indiv.", options->nmlength));
     }
 }
 
@@ -890,22 +907,22 @@ create_alleles (data_fmt * data)
     {
       z = 0;
       for (pop = 0; pop < data->numpop; pop++)
-	{
-	  for (ind = 0; ind < data->numind[pop][locus]; ind++)
-	    {
-	      strcpy (a1, data->yy[pop][ind][locus][0]);
-	      strcpy (a2, data->yy[pop][ind][locus][1]);
-	      if (!strcmp (a1, a2))
-		{
-		  addAllele (data, a1, locus, &z);
-		}
-	      else
-		{
-		  addAllele (data, a1, locus, &z);
-		  addAllele (data, a2, locus, &z);
-		}
-	    }
-	}
+        {
+          for (ind = 0; ind < data->numind[pop][locus]; ind++)
+            {
+              strcpy (a1, data->yy[pop][ind][locus][0]);
+              strcpy (a2, data->yy[pop][ind][locus][1]);
+              if (!strcmp (a1, a2))
+                {
+                  addAllele (data, a1, locus, &z);
+                }
+              else
+                {
+                  addAllele (data, a1, locus, &z);
+                  addAllele (data, a2, locus, &z);
+                }
+            }
+        }
       data->maxalleles[locus] = z + 1;
       /* + 1: for all the unencountered alleles */
     }
@@ -916,7 +933,7 @@ addAllele (data_fmt * data, char s[], long locus, long *z)
 {
   long found = 0;
   while ((data->allele[locus][found++][0] != '\0')
-	 && (strcmp (s, data->allele[locus][found - 1])))
+         && (strcmp (s, data->allele[locus][found - 1])))
     ;
   if (found > (*z))
     {
@@ -932,16 +949,16 @@ set_numind (data_fmt * data)
   for (locus = 1; locus < data->loci; locus++)
     {
       for (pop = 0; pop < data->numpop; pop++)
-	{
-	  data->numind[pop][locus] = data->numind[pop][FLOC];
-	}
+        {
+          data->numind[pop][locus] = data->numind[pop][FLOC];
+        }
     }
 }
 
 
 void
 print_seq_pop (long locus, long pop, world_fmt * world, option_fmt * options,
-	       data_fmt * data)
+               data_fmt * data)
 {
   long ind;
   for (ind = 0; ind < data->numind[pop][locus]; ind++)
@@ -952,29 +969,29 @@ print_seq_pop (long locus, long pop, world_fmt * world, option_fmt * options,
 
 void
 print_seq_ind (long locus, long pop, long ind, world_fmt * world,
-	       option_fmt * options, data_fmt * data)
+               option_fmt * options, data_fmt * data)
 {
   long site;
   char blank[2] = " ";
   fprintf (world->outfile, "%-*.*s", (int) options->nmlength,
-	   (int) options->nmlength, data->indnames[pop][ind]);
+           (int) options->nmlength, data->indnames[pop][ind]);
   fprintf (world->outfile, " %c", data->yy[pop][ind][locus][0][0]);
   for (site = 1; site < data->seq->sites[locus]; site++)
     {
       if ((site) % 60 == 0)
-	{
-	  fprintf (world->outfile, "\n%-*.*s %c", (int) options->nmlength,
-		   (int) options->nmlength, blank,
-		   data->yy[pop][ind][locus][0][site]);
-	}
+        {
+          fprintf (world->outfile, "\n%-*.*s %c", (int) options->nmlength,
+                   (int) options->nmlength, blank,
+                   data->yy[pop][ind][locus][0][site]);
+        }
       else
-	{
-	  if ((site) % 10 == 0)
-	    {
-	      fprintf (world->outfile, " ");
-	    }
-	  fprintf (world->outfile, "%c", data->yy[pop][ind][locus][0][site]);
-	}
+        {
+          if ((site) % 10 == 0)
+            {
+              fprintf (world->outfile, " ");
+            }
+          fprintf (world->outfile, "%c", data->yy[pop][ind][locus][0][site]);
+        }
     }
   fprintf (world->outfile, "\n");
 }
@@ -982,13 +999,13 @@ print_seq_ind (long locus, long pop, long ind, world_fmt * world,
 
 void
 print_locus_head (long locus, world_fmt * world, option_fmt * options,
-		  data_fmt * data)
+                  data_fmt * data)
 {
   char *head;
   head = (char *) calloc (1, sizeof (char) * MAX (10, options->nmlength));
   sprintf (head, "Locus %li", locus);
   fprintf (world->outfile, "%-*.*s --------10 --------20 --------30",
-	   (int) options->nmlength, (int) options->nmlength, head);
+           (int) options->nmlength, (int) options->nmlength, head);
   fprintf (world->outfile, " --------40 --------50 --------60\n");
 
   free (head);
@@ -1004,27 +1021,29 @@ read_geofile (data_fmt * data, option_fmt * options, long numpop)
   if (!options->geo)
     {
       for (i = 0; i < numpop2; i++)
-	data->geo[i] = 1.0;
+        data->geo[i] = 1.0;
     }
   else
     {
       data->ogeo = (double **) calloc (1, sizeof (double *) * numpop);
       data->ogeo[0] = (double *) calloc (1, sizeof (double) * numpop2);
       for (pop = 1; pop < numpop; pop++)
-	data->ogeo[pop] = data->ogeo[0] + numpop * pop;
+        data->ogeo[pop] = data->ogeo[0] + numpop * pop;
       read_distance_fromfile (data->geofile, numpop, options->nmlength,
-			      data->ogeo);
+                              data->ogeo);
       for (i = 0; i < numpop; i++)
-	for (j = i + 1; j < numpop; j++)
-	  {
-
-	    data->geo[mm2m (i, j, numpop)] = data->geo[mm2m (j, i, numpop)] =
-	      1. / data->ogeo[i][j];
-	    data->lgeo[mm2m (i, j, numpop)] =
-	      data->lgeo[mm2m (j, i, numpop)] =
-	      data->ogeo[i][j] > 0.0 ? log (1. / data->ogeo[i][j]) : -DBL_MAX;
-	  }
-    }
+        {
+		  for (j = 0; j < numpop; j++)
+			{
+			  if(i!=j)
+				{
+				  data->geo[mm2m (i, j, numpop)] =   1. / data->ogeo[i][j];
+				  data->lgeo[mm2m (i, j, numpop)] =  data->ogeo[i][j] > 0.0 ?
+					  log (1. / data->ogeo[i][j]) : -DBL_MAX;
+				}
+			}
+		}
+	}
 }
 
 #ifdef UEP
@@ -1039,10 +1058,10 @@ read_uepfile (data_fmt * data, option_fmt * options, long numpop)
 
   for (i = 0; i < numpop; ++i)
     sumtips += data->numind[i][FLOC];
-  data->uep = (long **) calloc (number_genomes (options->datatype) * sumtips,
-				sizeof (long *));
+  data->uep = (int **) calloc (number_genomes (options->datatype) * sumtips,
+                               sizeof (int *));
   read_uep_fromfile (data->uepfile, sumtips, options->nmlength, data->uep,
-		     &data->uepsites, options->datatype);
+                     &data->uepsites, options->datatype);
 }
 
 #endif
