@@ -4,7 +4,7 @@
 /*-----------------------------------------------------------------
   Maximum likelihood estimation of migration rates 
   using coalescent trees
-
+ 
   Peter Beerli
   Genetics 357360
   University of Washington
@@ -13,16 +13,16 @@
  
   With help of Joe Felsenstein (joe@genetics.washington.edu),
   Mary Kuhner and Jon Yamato (mkkuhner@genetics.washington.edu)
-
+ 
   
 Copyright 2001 Peter Beerli and Joseph Felsenstein
-
+ 
 $Id: definitions.h,v 1.65 2001/09/07 23:56:13 beerli Exp $
-
+ 
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "1.3"
+#define MIGRATEVERSION "1.5"
 #endif
 
 #define MAINTAINER "Peter Beerli <beerli@genetics.washington.edu>"
@@ -78,6 +78,7 @@ $Id: definitions.h,v 1.65 2001/09/07 23:56:13 beerli Exp $
 #define BOOTFILE "bootstrapfile"
 #define UEPFILE "uepfile"
 #define AICFILE "aicfile"
+#define BAYESFILE "bayesfile"
 #ifdef __STDIO_LOADED
 #define VMS
 #define MACHINE_TYPE "VAX/VMS C"
@@ -117,11 +118,18 @@ void vax_tweak_fmt (char *);
 /* redefinitions of calloc, malloc, realloc are in sighandler.h*/
 #define LAMARC_MALLOC
 #endif
+
+#ifdef HAVE_DEBUGMPI
+/* add print messages to mpi commands */
+#define DEBUG_MPI
+#endif
+
 #ifdef HAVE_LGAMMA
 #define LGAMMA lgamma
 #else
 #define LGAMMA mylgamma
 #endif
+
 #include "sighandler.h"
 #define FClose(file) if (file) fclose(file) ; file=NULL
 typedef unsigned char boolean;
@@ -151,6 +159,12 @@ typedef unsigned char boolean;
 #define EXP(a)  exp ((a))
 #endif
 
+// I was experimenting with a fast log implementation
+// but it is
+//not fast enough #define LOG(a) ((double) fast_log(((float) a)))
+// so back to standard log
+#define LOG(a) log((a))
+
 /* defines for speedier calc_like when we do NOT use undefined SLOWNET*/
 #ifdef SLOWNET
 #define CALCLIKE (*calc_like)
@@ -167,13 +181,13 @@ typedef unsigned char boolean;
 #endif
 /*=================================================================
   SPECIFIC FOR MIGRATE
-
+ 
   *----------------------------------------------------------------
   + = works
   - = not yet implemented (needed?)
-
+ 
   */
-/* number of k int k-allele model, the number  
+/* number of k int k-allele model, the number
    MUST really be bigger than the number of 
    observed alleles, much bigger does not harm	*/
 #define MAXALLELES            93
@@ -187,6 +201,7 @@ typedef unsigned char boolean;
 #define NUMPOP 2
 #define BURNINPERIOD 10000
 #define SCALEINTERVAL 5
+#define DEFAULTALLOCSIZE 2
 /* don't change below here ------------------------------------
    some other constants */
 /* numerical borders and epsilons*/
@@ -195,9 +210,10 @@ typedef unsigned char boolean;
 #define EPSILON4        0.000099	/* another small number */
 #define SMALLEPSILON       1e-15	/* a smaller number */
 #define BIGEPSILON         0.001	/* a not so small number */
-#define LONGCHAINEPSILON  10e100	/* an unreasonable big number, 
-					   so that the given number of 
-					   long chains is used */
+#define LONGCHAINEPSILON  10e100	/* an unreasonable big number,
+
+so that the given number of
+long chains is used */
 #define GELMAN_MYSTIC_VALUE 1.2
 #define PLUSCHAIN 10
 #ifndef MAXLONG
@@ -238,6 +254,9 @@ typedef unsigned char boolean;
 #define BIGGEST_THETA	     1e4
 #define SMALLEST_MIGRATION 1e-10
 #define BIGGEST_MIGRATION   10e9
+// defines the value that is used as a minimum summary statistic for migraiton events on all trees
+// version 1.2.4 had a value of 0.00000001, it seems that values of 0.1 are too large.
+#define MINMIGSUMSTAT 0.001
 /* the migration limit is per population, should be plenty
    for moderate sample sizes */
 #define MIGRATION_LIMIT     5000
@@ -271,6 +290,11 @@ typedef unsigned char boolean;
 /* the SANKOFF_DELTA should be smaller than any cost_ij*/
 #define SANKOFF_DELTA 0.1
 /* Maximizer and gamma things */
+#define STD22 1.0 /*0.1*/  /*"standard deviation" for penalizer 2*std*std=2*0.223607^2 */
+#define STD2 1.0 /*0.05*/  /* std*std = 0.223607^2 */
+#define LOGSTD 0.0 /*-1.49786613677699549672*/ /*LOG(std)*/
+//#define INVTWOSQRTPILOGSTD /*0.57892760357232275494*/ /* log(1/(std sqrt[2 pi])) */
+#define INVTWOSQRTPILOGSTD -0.91893853320467274178
 #define NTRIALS             1000
 #define LOCI_NORM          0.00001
 #define GAMMA_INTERVALS       10
