@@ -1,26 +1,26 @@
 /* Joint chain estimator
 Peter Beerli January 2000
-
+ 
 Copyright 2001 Peter Beerli and Joseph Felsenstein
-
+ 
 $Id: joint-chains.c,v 1.16 2001/09/07 23:56:13 beerli Exp $
-
+ 
 like(param) = Sum_g^G   ( p(g|param)/ L(param_j))
-
+ 
 denom = Sum_j^chains (n_j P(g|param0_j) / L(param_j)
-
+ 
 - pick param
 - calc chainparamlike
 - solve paramlike iteratively
 - maximize paramlike
-
+ 
 coaliter
     thetaval -> lthetai at theti[locus][lastchain]
     cycle through interp   -> new lthetai using theti[locus][chain] 
                       ((newth-lthetai)>epsilon) 
     estimate_parameter last chain
     estimate_parameter many chains
-
+ 
 */
 #include "migration.h"
 #include "broyden.h"
@@ -44,18 +44,19 @@ create_multiapg0 (double *apg0, nr_fmt * nr, long rep, long locus)
     {
       tmpmax = -DBL_MAX;
       for (r = nr->repstart; r < nr->repstop; r++)
-	{
-	  tmp[r] = -reps +
-	    probG (nr->world->atl[r][locus].param0,
-		   nr->world->atl[r][locus].lparam0,
-		   &nr->world->atl[rep][locus].tl[g], nr, locus)
-	    - (nr->world->chainlikes[locus][r]);
-	  if (tmp[r] > tmpmax)
-	    tmpmax = tmp[r];
-	}
+        {
+          tmp[r] = -reps +
+                   probG (nr->world->atl[r][locus].param0,
+                          nr->world->atl[r][locus].lparam0,
+                          &nr->world->atl[rep][locus].tl[g], nr, locus)
+                   - (nr->world->chainlikes[locus][r]);
+          
+          if (tmp[r] > tmpmax)
+            tmpmax = tmp[r];
+        }
       apg0[g] = 0.0;
       for (r = nr->repstart; r < nr->repstop; r++)
-	apg0[g] += EXP (tmp[r] - tmpmax);
+        apg0[g] += EXP (tmp[r] - tmpmax);
       apg0[g] = log (apg0[g]) + tmpmax;
     }
   free (tmp);
@@ -73,12 +74,16 @@ interpolate_like (nr_fmt * nr, long locus)
   double delta = 0.;
 
   boolean diffdone;
-  double *oldlike = nr->world->chainlikes[locus];
+  double *oldlike;
+  double *chainlike = nr->world->chainlikes[locus];
+  oldlike = (double *) calloc (repdiff, sizeof (double));  
+  memcpy (oldlike, chainlike, sizeof (double) * repdiff);
+
   newlike = (double *) calloc (repdiff, sizeof (double));
   diff = (double *) calloc (repdiff, sizeof (double));
   oldiff = (double *) calloc (repdiff, sizeof (double));
   lparam = (double *) calloc (nr->numpop2, sizeof (double));
-  /* following material is reverse logistic regression 
+  /* following material is reverse logistic regression
      a la Geyer 1994 */
   z = 0;
   alldone = FALSE;
@@ -88,53 +93,48 @@ interpolate_like (nr_fmt * nr, long locus)
     {
       alldone = TRUE;
       for (r = nr->repstart; r < nr->repstop; r++)
-	create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
+        create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
       for (j = nr->repstart; j < nr->repstop; j++)
-	{
-	  newlike[j] = calc_locus_like (nr, nr->atl[j][locus].param0,
-					nr->atl[j][locus].lparam0, locus);
-	  //newlike[j] = norm_constant(nr, nr->atl[j][locus].param0,
-	  //     nr->atl[j][locus].lparam0, locus);
-	  diff[j] = fabs (newlike[j] - oldlike[j]);
-	  if (delta < diff[j])
-	    delta = diff[j];
-	  if (delta > EPSILON)
-	    alldone = FALSE;
-	}
+        {
+          newlike[j] = calc_locus_like (nr, nr->atl[j][locus].param0,
+                                        nr->atl[j][locus].lparam0, locus);
+          //newlike[j] = norm_constant(nr, nr->atl[j][locus].param0,
+          //     nr->atl[j][locus].lparam0, locus);
+          diff[j] = fabs (newlike[j] - oldlike[j]);
+          if (delta < diff[j])
+            delta = diff[j];
+          if (delta > EPSILON)
+            alldone = FALSE;
+        }
 
       if (nr->world->options->progress)
-	if (z % 100 == 0 && nr->world->options->verbose)
-	  printf ("           Iteration%6li biggest difference = %f\n", z,
-		  delta);
+        if (z % 100 == 0 && nr->world->options->verbose)
+          printf ("           Iteration%6li biggest difference = %f\n", z,
+                  delta);
       memcpy (oldlike, newlike, sizeof (double) * repdiff);
       diffdone = TRUE;
       for (j = nr->repstart; j < nr->repstop; j++)
-	{
-	  if (fabs (oldiff[j] - diff[j]) > EPSILON)
-	    {
-	      diffdone = FALSE;
-	      break;
-	    }
-	}
+        {
+          if (fabs (oldiff[j] - diff[j]) > EPSILON)
+            {
+              diffdone = FALSE;
+              break;
+            }
+        }
       if (diffdone)
-	break;
+        break;
       else
-	memcpy (oldiff, diff, sizeof (double) * repdiff);
+        memcpy (oldiff, diff, sizeof (double) * repdiff);
       delta = diff[0];
     }
-  if (nr->world->options->progress || diffdone)
+  if ((nr->world->options->progress || diffdone) && delta > EPSILON)
     {
-      if (delta < EPSILON)
-	printf ("           Reweighting of chains finished in %li cycles\n",
-		z);
-      else
-	{
 	  printf ("           Reweighting operation converged to\n");
 	  printf ("           constant multiplier %f in %li cycles\n",
-		  delta, z);
-	}
+		   delta, z);
     }
   free (newlike);
+  free(oldlike);
   free (diff);
   free (oldiff);
   free (lparam);
