@@ -6,18 +6,18 @@
  using a Metropolis-Hastings Monte Carlo algorithm                            
  -------------------------------------------------------                        
  M C M C   R O U T I N E S 
-
+ 
  Markov Monte Carlo stuff: treechange, acceptance
  
-
+ 
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
-
+ 
 $Id: mcmc.h,v 1.4 2001/06/02 21:40:21 beerli Exp $
 -------------------------------------------------------*/
 
-extern long metropolize (world_fmt * world, long g);
+extern long tree_update (world_fmt * world, long g);
 extern void free_timevector (timelist_fmt * timevector);
 #endif
