@@ -4,20 +4,21 @@
  using a Metropolis-Hastings Monte Carlo algorithm                            
  -------------------------------------------------------                        
  M C M C 2   R O U T I N E S 
-
+ 
  Tree changing routines
  
-
+ 
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
-
+ 
 $Id: mcmc2.c,v 1.17 2001/07/25 19:27:24 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
 #include "tree.h"
+#include "uep.h"
 
 #ifdef DMALLOC_FUNC_CHECK
 #include <dmalloc.h>
@@ -67,7 +68,7 @@ void localevaluate (node * mother);
 void copy_x (proposal_fmt * proposal, xarray_fmt xx1, xarray_fmt xx2);
 void fix_root_pop (node * p);
 void pseudoevaluate (proposal_fmt * proposal, xarray_fmt x, double *lx,
-		     node * mother, node * newdaughter, double v);
+                     node * mother, node * newdaughter, double v);
 node *crawl_down (node * theNode, double tyme);
 
 
@@ -84,82 +85,82 @@ coalesce1p (proposal_fmt * proposal)
     {
       coat_ocousin (proposal);
       if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme
-	  && crawlback (proposal->oback)->type != 'r')
-	error ("problem with time encountered");	/* was >= ** */
+          && crawlback (proposal->oback)->type != 'r')
+        error ("problem with time encountered");	/* was >= ** */
     }
   else
     {
       if (((proposal->target == proposal->oback)
-	   || (proposal->target == proposal->osister)
-	   || (proposal->target == proposal->origin)))
-	{
-	  obb = proposal->oback->back;
-	  coat_oback (proposal);
-	  if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme)
-	    {			/* was >= ** */
-	      if (proposal->oback->back->type == 'r')
-		{
-		  adjust (proposal->root, proposal->oback->tyme + 10000, 0);
-		  comment ("Root time adjusted: was to small");
-		}
-	      else
-		error ("problem with time encountered");
-	    }
-	}
+           || (proposal->target == proposal->osister)
+           || (proposal->target == proposal->origin)))
+        {
+          obb = proposal->oback->back;
+          coat_oback (proposal);
+          if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme)
+            {			/* was >= ** */
+              if (proposal->oback->back->type == 'r')
+                {
+                  adjust (proposal->root, proposal->oback->tyme + 10000, 0);
+                  comment ("Root time adjusted: was to small");
+                }
+              else
+                error ("problem with time encountered");
+            }
+        }
       else
-	{
-	  if (crawlback (proposal->target)->type == 'r')
-	    {
-	      coat_rbcoa (proposal);
-	      if (proposal->oback->tyme >
-		  showtop (proposal->oback->back)->tyme)
-		{		/* was >= ** */
-		  if (proposal->oback->back->type == 'r')
-		    {
-		      adjust (proposal->root, proposal->oback->tyme + 10000,
-			      0);
-		      comment ("Root time adjusted: was to small");
-		    }
-		  else
-		    error ("problem with time encountered");
-		}
-	    }
-	  else
-	    {
-	      obb = showtop (crawlback (proposal->oback));
-	      if ((obb != NULL) && (obb == proposal->target))
-		{
-		  coat_obbcoa (proposal);
-		  if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme)	/* was >= ** */
-		    error ("problem with time encountered");
-		}
-	      else
-		{
-		  coat_stancoa (proposal);
-		  if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme)	/* was >= ** */
-		    error ("problem with time encountered");
-		}
-	    }
-	}
+        {
+          if (crawlback (proposal->target)->type == 'r')
+            {
+              coat_rbcoa (proposal);
+              if (proposal->oback->tyme >
+                  showtop (proposal->oback->back)->tyme)
+                {		/* was >= ** */
+                  if (proposal->oback->back->type == 'r')
+                    {
+                      adjust (proposal->root, proposal->oback->tyme + 10000,
+                              0);
+                      comment ("Root time adjusted: was to small");
+                    }
+                  else
+                    error ("problem with time encountered");
+                }
+            }
+          else
+            {
+              obb = showtop (crawlback (proposal->oback));
+              if ((obb != NULL) && (obb == proposal->target))
+                {
+                  coat_obbcoa (proposal);
+                  if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme)	/* was >= ** */
+                    error ("problem with time encountered");
+                }
+              else
+                {
+                  coat_stancoa (proposal);
+                  if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme)	/* was >= ** */
+                    error ("problem with time encountered");
+                }
+            }
+        }
     }
   set_pop (proposal->oback, proposal->origin->actualpop,
-	   proposal->origin->actualpop);
-/*   free_migr_node(proposal->origin, crawlback(proposal->origin)); */
+           proposal->origin->actualpop);
+  /*   free_migr_node(proposal->origin, crawlback(proposal->origin)); */
   if (proposal->migr_table_counter > 0)
     {
       set_pop (proposal->oback,
-	       proposal->migr_table[proposal->migr_table_counter - 1].from,
-	       proposal->migr_table[proposal->migr_table_counter - 1].from);
+               proposal->migr_table[proposal->migr_table_counter - 1].from,
+               proposal->migr_table[proposal->migr_table_counter - 1].from);
       insert_migr_node (proposal->world, proposal->origin,
-			crawlback (proposal->origin), proposal->migr_table,
-			&(proposal->migr_table_counter));
+                        crawlback (proposal->origin), proposal->migr_table,
+                        &(proposal->migr_table_counter));
     }
   proposal->migr_table_counter = 0;
   if (proposal->migr_table_counter2)
     {
       insert_migr_node (proposal->world, proposal->realtarget,
-			crawlback (proposal->target), proposal->migr_table2,
-			&(proposal->migr_table_counter2));
+                        crawlback (proposal->target), proposal->migr_table2,
+                        &(proposal->migr_table_counter2));
       proposal->migr_table_counter2 = 0;
     }
   /*    if (proposal->oback == crawlback(proposal->root->next)) */
@@ -178,31 +179,31 @@ pretendcoalesce1p (proposal_fmt * proposal)
   else
     {
       if (((proposal->target == proposal->oback)
-	   || (proposal->target == proposal->osister)
-	   || (proposal->target == proposal->origin)))
-	{
-	  target_oback (proposal);
-	}
+           || (proposal->target == proposal->osister)
+           || (proposal->target == proposal->origin)))
+        {
+          target_oback (proposal);
+        }
       else
-	{
-	  if (crawlback (proposal->target)->type == 'r')
-	    {
-	      target_rbcoa (proposal);
-	    }
-	  else
-	    {
-	      if ((showtop (crawlback (proposal->oback)) != NULL)
-		  && (showtop (crawlback (proposal->oback)) ==
-		      proposal->target))
-		{
-		  target_obbcoa (proposal);
-		}
-	      else
-		{
-		  target_stancoa (proposal);
-		}
-	    }
-	}
+        {
+          if (crawlback (proposal->target)->type == 'r')
+            {
+              target_rbcoa (proposal);
+            }
+          else
+            {
+              if ((showtop (crawlback (proposal->oback)) != NULL)
+                  && (showtop (crawlback (proposal->oback)) ==
+                      proposal->target))
+                {
+                  target_obbcoa (proposal);
+                }
+              else
+                {
+                  target_stancoa (proposal);
+                }
+            }
+        }
     }
 }
 
@@ -223,7 +224,7 @@ coat_oback (proposal_fmt * proposal)
   else
     {
       if (obm->type == 'm')
-	connectnodes (obm, proposal->oback, NULL);
+        connectnodes (obm, proposal->oback, NULL);
       connectnodes (obb, proposal->oback, proposal->ocousin);
     }
   adjust (obb, obb->tyme, 2);
@@ -291,10 +292,10 @@ coat_obbcoa (proposal_fmt * proposal)
       proposal->oback->back = NULL;
       adjust_time (proposal->oback, proposal->time);
       if (showtop (proposal->realtarget->back)->type == 'm')
-	{
-	  connectnodes (showtop (proposal->realtarget->back), proposal->oback,
-			NULL);
-	}
+        {
+          connectnodes (showtop (proposal->realtarget->back), proposal->oback,
+                        NULL);
+        }
       connectnodes (proposal->oback, proposal->origin, proposal->target);
       connectnodes (proposalack, proposal->tsister, proposal->oback);
       adjust (proposalack, proposalack->tyme, 2);
@@ -321,8 +322,8 @@ coat_stancoa (proposal_fmt * proposal)
       connectnodes (obb, proposal->osister, proposal->ocousin);
       adjust_time (proposal->oback, proposal->time);
       if (showtop (proposal->realtarget->back)->type == 'm')
-	connectnodes (showtop (proposal->realtarget->back), proposal->oback,
-		      NULL);
+        connectnodes (showtop (proposal->realtarget->back), proposal->oback,
+                      NULL);
       connectnodes (proposal->oback, proposal->origin, proposal->target);
       connectnodes (proposalack, proposal->oback, proposal->tsister);
       adjust (proposalack, proposalack->tyme, 3);
@@ -341,8 +342,8 @@ coat_stancoa (proposal_fmt * proposal)
       adjust_time (proposal->oback, proposal->time);
       proposal->oback->back = NULL;
       if (showtop (proposal->realtarget->back)->type == 'm')
-	connectnodes (showtop (proposal->realtarget->back), proposal->oback,
-		      NULL);
+        connectnodes (showtop (proposal->realtarget->back), proposal->oback,
+                      NULL);
       connectnodes (proposal->oback, proposal->origin, proposal->target);
       connectnodes (proposalack, proposal->oback, proposal->tsister);
       /* either proposalack is osister or a descendent of her
@@ -362,14 +363,20 @@ target_oback (proposal_fmt * proposal)
 {
   node *obb = showtop (crawlback (proposal->oback));
   copy_x (proposal, proposal->xf, proposal->origin->x);
+#ifdef UEP
+
+  if(proposal->world->options->uep)
+    copy_uepx(proposal,proposal->uf, proposal->origin->ux);
+#endif
+
   memcpy (proposal->mf, proposal->origin->scale,
-	  sizeof (double) * proposal->endsite);
+          sizeof (double) * proposal->endsite);
   proposal->v = (proposal->time - proposal->origin->tyme);
   proposal->vs = (proposal->time - proposal->osister->tyme);
   pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-		proposal->osister->x, proposal->osister->scale, proposal->vs);
+                proposal->osister->x, proposal->osister->scale, proposal->vs);
   pseudoevaluate (proposal, proposal->xf, proposal->mf, obb, proposal->oback,
-		  fabs (proposal->time - obb->tyme));
+                  fabs (proposal->time - obb->tyme));
 }
 
 void
@@ -378,22 +385,34 @@ target_ocousin (proposal_fmt * proposal)
   node *obb;
   obb = showtop (crawlback (proposal->oback));
   copy_x (proposal, proposal->xf, proposal->origin->x);
+#ifdef UEP
+
+  if(proposal->world->options->uep)
+    copy_uepx(proposal,proposal->uf, proposal->origin->ux);
+#endif
+
   memcpy (proposal->mf, proposal->origin->scale,
-	  sizeof (double) * proposal->endsite);
+          sizeof (double) * proposal->endsite);
   copy_x (proposal, proposal->xt, proposal->ocousin->x);
+#ifdef UEP
+
+  if(proposal->world->options->uep)
+    copy_uepx(proposal,proposal->ut, proposal->ocousin->ux);
+#endif
+
   memcpy (proposal->mt, proposal->ocousin->scale,
-	  sizeof (double) * proposal->endsite);
+          sizeof (double) * proposal->endsite);
   proposal->v = (proposal->time - proposal->origin->tyme);
   proposal->vs = fabs (proposal->ocousin->tyme - proposal->time);
   pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-		proposal->xt, proposal->mt, proposal->vs);
+                proposal->xt, proposal->mt, proposal->vs);
   proposal->v = fabs (proposal->time - obb->tyme);
   proposal->vs = obb->tyme - proposal->osister->tyme;
   pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-		proposal->osister->x, proposal->osister->scale, proposal->vs);
+                proposal->osister->x, proposal->osister->scale, proposal->vs);
   pseudoevaluate (proposal, proposal->xf, proposal->mf,
-		  showtop (crawlback (obb)), obb,
-		  (showtop (crawlback (obb))->tyme - obb->tyme));
+                  showtop (crawlback (obb)), obb,
+                  (showtop (crawlback (obb))->tyme - obb->tyme));
 }
 
 void
@@ -406,21 +425,33 @@ target_rbcoa (proposal_fmt * proposal)
       proposal->vs = obb->tyme - proposal->osister->tyme;
       proposal->v = obb->tyme - proposal->ocousin->tyme;
       copy_x (proposal, proposal->xt, proposal->osister->x);
+#ifdef UEP
+
+      if(proposal->world->options->uep)
+        copy_uepx(proposal,proposal->ut, proposal->osister->ux);
+#endif
+
       memcpy (proposal->mt, proposal->osister->scale,
-	      sizeof (double) * proposal->endsite);
+              sizeof (double) * proposal->endsite);
       pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs,
-		    proposal->ocousin->x, proposal->ocousin->scale,
-		    proposal->v);
+                    proposal->ocousin->x, proposal->ocousin->scale,
+                    proposal->v);
       pseudoevaluate (proposal, proposal->xt, proposal->mt,
-		      showtop (crawlback (obb)), obb,
-		      showtop (crawlback (obb))->tyme - obb->tyme);
+                      showtop (crawlback (obb)), obb,
+                      showtop (crawlback (obb))->tyme - obb->tyme);
       proposal->v = proposal->time - proposal->origin->tyme;
       proposal->vs = proposal->time - proposal->target->tyme;
       copy_x (proposal, proposal->xf, proposal->origin->x);
+#ifdef UEP
+
+      if(proposal->world->options->uep)
+        copy_uepx(proposal,proposal->uf, proposal->origin->ux);
+#endif
+
       memcpy (proposal->mf, proposal->origin->scale,
-	      sizeof (double) * proposal->endsite);
+              sizeof (double) * proposal->endsite);
       pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-		    proposal->xt, proposal->mt, proposal->vs);
+                    proposal->xt, proposal->mt, proposal->vs);
     }
   else
     {
@@ -438,22 +469,34 @@ target_obbcoa (proposal_fmt * proposal)
       proposal->vs = obb->tyme - proposal->osister->tyme;
       proposal->v = obb->tyme - proposal->ocousin->tyme;
       copy_x (proposal, proposal->xt, proposal->osister->x);
+#ifdef UEP
+
+      if(proposal->world->options->uep)
+        copy_uepx(proposal,proposal->ut, proposal->osister->ux);
+#endif
+
       memcpy (proposal->mt, proposal->osister->scale,
-	      sizeof (double) * proposal->endsite);
+              sizeof (double) * proposal->endsite);
       pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs,
-		    proposal->ocousin->x, proposal->ocousin->scale,
-		    proposal->v);
+                    proposal->ocousin->x, proposal->ocousin->scale,
+                    proposal->v);
       proposal->v = proposal->time - proposal->origin->tyme;
       proposal->vs = fabs (obb->tyme - proposal->time);
       copy_x (proposal, proposal->xf, proposal->origin->x);
+#ifdef UEP
+
+      if(proposal->world->options->uep)
+        copy_uepx(proposal,proposal->uf, proposal->origin->ux);
+#endif
+
       memcpy (proposal->mf, proposal->origin->scale,
-	      sizeof (double) * proposal->endsite);
+              sizeof (double) * proposal->endsite);
       pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-		    proposal->xt, proposal->mt, proposal->vs);
+                    proposal->xt, proposal->mt, proposal->vs);
       proposal->v = fabs (showtop (crawlback (obb))->tyme - proposal->time);
       obbb = showtop (crawlback (obb));
       pseudoevaluate (proposal, proposal->xf, proposal->mf, obbb, obb,
-		      proposal->v);
+                      proposal->v);
     }
   else
     {
@@ -472,84 +515,108 @@ target_stancoa (proposal_fmt * proposal)
       obb = showtop (crawlback (proposal->oback));
       gotoroot (proposal->target, proposal->line_t);
       double_line[0] = proposal->osister;
-/*findcrossing needs a last NULL element */
+      /*findcrossing needs a last NULL element */
       if (findcrossing (double_line, proposal->line_t) != NULL)
-	{
-	  t_s_upper (proposal, proposal->osister, obb);
-	}
+        {
+          t_s_upper (proposal, proposal->osister, obb);
+        }
       else
-	{
-	  double_line[0] = proposal->ocousin;
-/*findcrossing needs a last NULL element */
-	  if (findcrossing (double_line, proposal->line_t) != NULL)
-	    {
-	      t_s_upper (proposal, proposal->ocousin, obb);
-	    }
-	  else
-	    {
-	      gotoroot (obb, proposal->line_f);
-	      proposal->connect =
-		findcrossing (proposal->line_f, proposal->line_t);
-	      proposal->vs = obb->tyme - proposal->osister->tyme;
-	      proposal->v = obb->tyme - proposal->ocousin->tyme;
-	      copy_x (proposal, proposal->xt, proposal->osister->x);
-	      memcpy (proposal->mt, proposal->osister->scale,
-		      sizeof (double) * proposal->endsite);
-	      /*       if (obb!=proposal->connect) { */
-	      upper = t_s_obbncon (proposal, obb);
-	      /*} */
-	      proposal->v = proposal->time - proposal->origin->tyme;
-	      copy_x (proposal, proposal->xf, proposal->origin->x);
-	      memcpy (proposal->mf, proposal->origin->scale,
-		      sizeof (double) * proposal->endsite);
-	      if (proposal->target != proposal->connect)
-		{
-		  t_s_tncon (proposal, obb);
-		}
-	      else
-		{
-		  t_s_tcon (proposal, upper);
-		}
-	    }
-	}
+        {
+          double_line[0] = proposal->ocousin;
+          /*findcrossing needs a last NULL element */
+          if (findcrossing (double_line, proposal->line_t) != NULL)
+            {
+              t_s_upper (proposal, proposal->ocousin, obb);
+            }
+          else
+            {
+              gotoroot (obb, proposal->line_f);
+              proposal->connect =
+                findcrossing (proposal->line_f, proposal->line_t);
+              proposal->vs = obb->tyme - proposal->osister->tyme;
+              proposal->v = obb->tyme - proposal->ocousin->tyme;
+              copy_x (proposal, proposal->xt, proposal->osister->x);
+#ifdef UEP
+
+              if(proposal->world->options->uep)
+                copy_uepx(proposal,proposal->ut, proposal->osister->ux);
+#endif
+
+              memcpy (proposal->mt, proposal->osister->scale,
+                      sizeof (double) * proposal->endsite);
+              /*       if (obb!=proposal->connect) { */
+              upper = t_s_obbncon (proposal, obb);
+              /*} */
+              proposal->v = proposal->time - proposal->origin->tyme;
+              copy_x (proposal, proposal->xf, proposal->origin->x);
+#ifdef UEP
+
+              if(proposal->world->options->uep)
+                copy_uepx(proposal,proposal->uf, proposal->origin->ux);
+#endif
+
+              memcpy (proposal->mf, proposal->origin->scale,
+                      sizeof (double) * proposal->endsite);
+              if (proposal->target != proposal->connect)
+                {
+                  t_s_tncon (proposal, obb);
+                }
+              else
+                {
+                  t_s_tcon (proposal, upper);
+                }
+            }
+        }
     }
   else
     {
       proposal->v = proposal->time - proposal->origin->tyme;
       proposal->vs = proposal->time - proposal->target->tyme;
       copy_x (proposal, proposal->xf, proposal->origin->x);
+#ifdef UEP
+
+      if(proposal->world->options->uep)
+        copy_uepx(proposal,proposal->uf, proposal->origin->ux);
+#endif
+
       memcpy (proposal->mf, proposal->origin->scale,
-	      sizeof (double) * proposal->endsite);
+              sizeof (double) * proposal->endsite);
       copy_x (proposal, proposal->xt, proposal->target->x);
+#ifdef UEP
+
+      if(proposal->world->options->uep)
+        copy_uepx(proposal,proposal->ut, proposal->target->ux);
+#endif
+
       memcpy (proposal->mt, proposal->target->scale,
-	      sizeof (double) * proposal->endsite);
+              sizeof (double) * proposal->endsite);
       //CHECK HEREH      memcpy(proposal->mt,proposal->osister->scale, sizeof(double)*proposal->endsite);
       pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-		    proposal->xt, proposal->mt, proposal->vs);
+                    proposal->xt, proposal->mt, proposal->vs);
       proposal->v =
-	fabs (((proposalack =
-		showtop (crawlback (proposal->target)))->tyme -
-	       proposal->time));
+        fabs (((proposalack =
+                  showtop (crawlback (proposal->target)))->tyme -
+               proposal->time));
       if (proposalack != proposal->oback)
-	{
-	  children (proposalack, &d1, &d2);
-	  if (d1 == proposal->target)
-	    d1 = d2;
-	  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-			d1->x, d1->scale, d1->v);
-	  oldnn = proposalack;
-	  nn = showtop (crawlback (oldnn));
-	  while (nn != proposal->oback)
-	    {
-	      children (nn, &d1, &d2);
-	      if (d1 == oldnn)
-		d1 = d2;
-	      pseudonuview (proposal, proposal->xf, proposal->mf, oldnn->v,
-			    d1->x, d1->scale, d1->v);
-	      oldnn = nn;
-	      nn = showtop (crawlback (nn));
-	    }
-	}
+        {
+          children (proposalack, &d1, &d2);
+          if (d1 == proposal->target)
+            d1 = d2;
+          pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+                        d1->x, d1->scale, d1->v);
+          oldnn = proposalack;
+          nn = showtop (crawlback (oldnn));
+          while (nn != proposal->oback)
+            {
+              children (nn, &d1, &d2);
+              if (d1 == oldnn)
+                d1 = d2;
+              pseudonuview (proposal, proposal->xf, proposal->mf, oldnn->v,
+                            d1->x, d1->scale, d1->v);
+              oldnn = nn;
+              nn = showtop (crawlback (nn));
+            }
+        }
     }
   free (double_line);
 }
@@ -561,10 +628,16 @@ t_s_upper (proposal_fmt * proposal, node * connect, node * obb)
   proposal->v = proposal->time - proposal->origin->tyme;
   proposal->vs = proposal->time - proposal->target->tyme;
   copy_x (proposal, proposal->xf, proposal->origin->x);
+#ifdef UEP
+
+  if(proposal->world->options->uep)
+    copy_uepx(proposal,proposal->uf, proposal->origin->ux);
+#endif
+
   memcpy (proposal->mf, proposal->origin->scale,
-	  sizeof (double) * proposal->endsite);
+          sizeof (double) * proposal->endsite);
   pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-		proposal->target->x, proposal->target->scale, proposal->vs);
+                proposal->target->x, proposal->target->scale, proposal->vs);
   nn = showtop (crawlback (proposal->target));
   oldnn = proposal->target;
   proposal->vs = fabs (nn->tyme - proposal->time);
@@ -572,9 +645,9 @@ t_s_upper (proposal_fmt * proposal, node * connect, node * obb)
     {
       children (nn, &d1, &d2);
       if (d1 == oldnn)
-	d1 = d2;
+        d1 = d2;
       pseudonuview (proposal, proposal->xf, proposal->mf, proposal->vs, d1->x,
-		    d1->scale, d1->v);
+                    d1->scale, d1->v);
       proposal->vs = nn->v;
       oldnn = nn;
       nn = showtop (crawlback (nn));
@@ -583,19 +656,19 @@ t_s_upper (proposal_fmt * proposal, node * connect, node * obb)
   if (d1 == oldnn)
     d1 = d2;
   pseudonuview (proposal, proposal->xf, proposal->mf, proposal->vs, d1->x,
-		d1->scale, d1->v);
+                d1->scale, d1->v);
   proposal->v = obb->tyme - proposal->osister->tyme;
   proposal->vs = obb->tyme - proposal->ocousin->tyme;
   if (connect == proposal->ocousin)
     pseudonuview (proposal, proposal->xf, proposal->mf, proposal->vs,
-		  proposal->osister->x, proposal->osister->scale,
-		  proposal->v);
+                  proposal->osister->x, proposal->osister->scale,
+                  proposal->v);
   else
     pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-		  proposal->ocousin->x, proposal->ocousin->scale,
-		  proposal->vs);
+                  proposal->ocousin->x, proposal->ocousin->scale,
+                  proposal->vs);
   pseudoevaluate (proposal, proposal->xf, proposal->mf,
-		  showtop (crawlback (obb)), obb, obb->v);
+                  showtop (crawlback (obb)), obb, obb->v);
 }
 
 node *
@@ -603,9 +676,9 @@ t_s_obbncon (proposal_fmt * proposal, node * obb)
 {
 
   node *nn, *oldnn, *d1, *d2;
-/*     fprintf(stdout,"t_s_obbncon\n"); */
+  /*     fprintf(stdout,"t_s_obbncon\n"); */
   pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs,
-		proposal->ocousin->x, proposal->ocousin->scale, proposal->v);
+                proposal->ocousin->x, proposal->ocousin->scale, proposal->v);
   nn = showtop (crawlback (obb));
   oldnn = obb;
   proposal->vs = fabs (nn->tyme - obb->tyme);
@@ -613,9 +686,9 @@ t_s_obbncon (proposal_fmt * proposal, node * obb)
     {
       children (nn, &d1, &d2);
       if (d1 == oldnn)
-	d1 = d2;
+        d1 = d2;
       pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs, d1->x,
-		    d1->scale, d1->v);
+                    d1->scale, d1->v);
       proposal->vs = nn->v;
       oldnn = nn;
       nn = showtop (crawlback (nn));
@@ -628,8 +701,8 @@ t_s_tncon (proposal_fmt * proposal, node * obb)
 {
   node *nn, *oldnn, *d1, *d2;
   pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-		proposal->target->x, proposal->target->scale,
-		proposal->time - proposal->target->tyme);
+                proposal->target->x, proposal->target->scale,
+                proposal->time - proposal->target->tyme);
   nn = showtop (crawlback (proposal->target));
   oldnn = proposal->target;
   proposal->v = fabs (nn->tyme - proposal->time);
@@ -637,20 +710,20 @@ t_s_tncon (proposal_fmt * proposal, node * obb)
     {
       children (nn, &d1, &d2);
       if (d1 == oldnn)
-	d1 = d2;
+        d1 = d2;
       pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, d1->x,
-		    d1->scale, d1->v);
+                    d1->scale, d1->v);
       proposal->v = nn->v;
       oldnn = nn;
       nn = showtop (crawlback (nn));
     }
   if (obb != proposal->connect)
     pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
-		  proposal->xt, proposal->mt, proposal->vs);
+                  proposal->xt, proposal->mt, proposal->vs);
   proposal->v = proposal->connect->v;
   pseudoevaluate (proposal, proposal->xf, proposal->mf,
-		  showtop (crawlback (proposal->connect)), proposal->connect,
-		  proposal->v);
+                  showtop (crawlback (proposal->connect)), proposal->connect,
+                  proposal->v);
 }
 
 void
@@ -672,11 +745,11 @@ t_s_tcon (proposal_fmt * proposal, node * upper)
     {
       children (obb, &d1, &d2);
       if (d1 == proposal->target)
-	d1 = d2;
+        d1 = d2;
       pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, d1->x,
-		    d1->scale, d1->v);
+                    d1->scale, d1->v);
       pseudoevaluate (proposal, proposal->xf, proposal->mf,
-		      showtop (crawlback (obb)), obb, obb->v);
+                      showtop (crawlback (obb)), obb, obb->v);
     }
 }
 
@@ -698,11 +771,11 @@ erase_migr_nodes (node * up)
       oldNode = theNode;
       theNode = theNode->next->back;
       if (oldNode->type == 'm')
-	{
-	  free (oldNode->next);
-	  free (oldNode);
-	  deleted++;
-	}
+        {
+          free (oldNode->next);
+          free (oldNode);
+          deleted++;
+        }
     }
 
 
@@ -725,10 +798,10 @@ connectnodes (node * mother, node * brother, node * sister)
   if ((sister != NULL) && (brother != NULL))
     {
       if ((mother->id == brother->id) || (mother->id == sister->id)
-	  || (sister->id == brother->id))
-	{
-	  error ("connectnodes() conflict");
-	}
+          || (sister->id == brother->id))
+        {
+          error ("connectnodes() conflict");
+        }
       tmp = crawl_down (brother, mother->tyme);
       mother->next->back = tmp;
       tmp->back = mother->next;
@@ -739,34 +812,34 @@ connectnodes (node * mother, node * brother, node * sister)
   else
     {
       if (sister == NULL)
-	{
-	  tmp = crawl_down (brother, mother->tyme);
-	  mother->next->back = tmp;
-	  tmp->back = mother->next;
-	}
+        {
+          tmp = crawl_down (brother, mother->tyme);
+          mother->next->back = tmp;
+          tmp->back = mother->next;
+        }
       else
-	{
+        {
 
-	  if (brother == NULL)
-	    {
-	      if (mother->type == 'm')
-		{
-		  tmp = crawl_down (sister, mother->tyme);
-		  mother->next->back = tmp;
-		  tmp->back = mother->next;
-		}
-	      else
-		{
-		  tmp = crawl_down (sister, mother->tyme);
-		  mother->next->next->back = tmp;
-		  tmp->back = mother->next->next;
-		}
-	    }
-	  else
-	    {
-	      error ("Single, lonely rootnode detected in connectenodes()\n");
-	    }
-	}
+          if (brother == NULL)
+            {
+              if (mother->type == 'm')
+                {
+                  tmp = crawl_down (sister, mother->tyme);
+                  mother->next->back = tmp;
+                  tmp->back = mother->next;
+                }
+              else
+                {
+                  tmp = crawl_down (sister, mother->tyme);
+                  mother->next->next->back = tmp;
+                  tmp->back = mother->next->next;
+                }
+            }
+          else
+            {
+              error ("Single, lonely rootnode detected in connectenodes()\n");
+            }
+        }
     }
 }
 
@@ -797,11 +870,11 @@ adjust (node * theNode, double tyme, long level)
       theNode->v = 1;
       theNode->length = DBL_MAX;
       if (theNode->next->back != NULL)
-	adjust (crawlback (theNode->next), crawlback (theNode->next)->tyme,
-		level);
+        adjust (crawlback (theNode->next), crawlback (theNode->next)->tyme,
+                level);
       if (theNode->next->next->back != NULL)
-	adjust (crawlback (theNode->next->next),
-		crawlback (theNode->next->next)->tyme, level);
+        adjust (crawlback (theNode->next->next),
+                crawlback (theNode->next->next)->tyme, level);
     }
   else if (theNode->type == 't')
     {
@@ -813,34 +886,34 @@ adjust (node * theNode, double tyme, long level)
   else if ((theNode->type != 't'))
     {
       if (theNode->type != 'm')
-	{
-	  theNode->length = lengthof (theNode);
-	  ltov (theNode);
-	  if (theNode->next->back != NULL)
-	    {
-	      theNode->next->tyme = tyme;
-	      theNode->next->v = theNode->v;
-	      theNode->next->length = theNode->length;
-	      adjust (crawlback (theNode->next),
-		      crawlback (theNode->next)->tyme, level - 1);
-	    }
-	  if (theNode->next->next->back != NULL)
-	    {
-	      theNode->next->next->tyme = tyme;
-	      theNode->next->next->v = theNode->v;
-	      theNode->next->next->length = theNode->length;
-	      adjust (crawlback (theNode->next->next),
-		      crawlback (theNode->next->next)->tyme, level - 1);
-	    }
-	}
+        {
+          theNode->length = lengthof (theNode);
+          ltov (theNode);
+          if (theNode->next->back != NULL)
+            {
+              theNode->next->tyme = tyme;
+              theNode->next->v = theNode->v;
+              theNode->next->length = theNode->length;
+              adjust (crawlback (theNode->next),
+                      crawlback (theNode->next)->tyme, level - 1);
+            }
+          if (theNode->next->next->back != NULL)
+            {
+              theNode->next->next->tyme = tyme;
+              theNode->next->next->v = theNode->v;
+              theNode->next->next->length = theNode->length;
+              adjust (crawlback (theNode->next->next),
+                      crawlback (theNode->next->next)->tyme, level - 1);
+            }
+        }
       else
-	adjust (crawlback (theNode->next), crawlback (theNode->next)->tyme,
-		level);
+        adjust (crawlback (theNode->next), crawlback (theNode->next)->tyme,
+                level);
     }
 }
 
 
-/* calculates x-array down the tree assuming that only one line 
+/* calculates x-array down the tree assuming that only one line
    is affected by the change of the sub-likelihoods above that line
    BUT does NOT calculate the tree-likelihood as evaluate() does.
    THIS CHANGES THE TREE
@@ -854,10 +927,10 @@ localevaluate (node * mother)
     {
       set_dirty (mother);
       for (nn = mother; crawlback (nn)->type != 'r';
-	   nn = showtop (crawlback (nn)))
-	{
-	  set_dirty (nn);
-	}
+           nn = showtop (crawlback (nn)))
+        {
+          set_dirty (nn);
+        }
     }
 }
 
@@ -871,20 +944,20 @@ copy_x (proposal_fmt * proposal, xarray_fmt xx1, xarray_fmt xx2)
     case 'b':
     case 'm':
       memcpy (xx1.a, xx2.a,
-	      sizeof (double) *
-	      proposal->world->data->maxalleles[proposal->world->locus]);
+              sizeof (double) *
+              proposal->world->data->maxalleles[proposal->world->locus]);
       break;
     case 's':
     case 'n':
     case 'u':
     case 'f':
       for (i = 0; i < proposal->endsite; i++)
-	{
-	  for (j = 0; j < proposal->world->options->rcategs; j++)
-	    {
-	      memcpy (xx1.s[i][j], xx2.s[i][j], sizeof (sitelike));
-	    }
-	}
+        {
+          for (j = 0; j < proposal->world->options->rcategs; j++)
+            {
+              memcpy (xx1.s[i][j], xx2.s[i][j], sizeof (sitelike));
+            }
+        }
       break;
     }
 }
@@ -905,14 +978,14 @@ fix_root_pop (node * p)
 }
 
 
-/* transfers an x-array down the tree assuming that only one line 
+/* transfers an x-array down the tree assuming that only one line
    is affected by the change of the sub-likelihoods above that line
    BUT does NOT calculate the tree-likelihood as evaluate() does.
    DOES NOT CHANGE THE TREE
  */
 void
 pseudoevaluate (proposal_fmt * proposal, xarray_fmt x, double *lx,
-		node * mother, node * newdaughter, double v)
+                node * mother, node * newdaughter, double v)
 {
   node *nn = NULL, *d1 = NULL, *d2 = NULL, *oldnn = NULL;
 
@@ -920,19 +993,19 @@ pseudoevaluate (proposal_fmt * proposal, xarray_fmt x, double *lx,
     {
       children (mother, &d1, &d2);
       if (d1 == newdaughter)
-	d1 = d2;
+        d1 = d2;
       pseudonuview (proposal, x, lx, v, d1->x, d1->scale, d1->v);
       oldnn = mother;
       nn = showtop (crawlback (mother));
       while (nn->type != 'r')
-	{
-	  children (nn, &d1, &d2);
-	  if (d1 == oldnn)
-	    d1 = d2;
-	  pseudonuview (proposal, x, lx, oldnn->v, d1->x, d1->scale, d1->v);
-	  oldnn = nn;
-	  nn = showtop (crawlback (nn));
-	}
+        {
+          children (nn, &d1, &d2);
+          if (d1 == oldnn)
+            d1 = d2;
+          pseudonuview (proposal, x, lx, oldnn->v, d1->x, d1->scale, d1->v);
+          oldnn = nn;
+          nn = showtop (crawlback (nn));
+        }
     }
 }
 
@@ -945,11 +1018,11 @@ findcrossing (node ** ptrl1, node ** ptrl2)
   for (i = 0; ptrl1[i] != NULL; j = 0, i++)
     {
       while ((ptrl1[i] != ptrl2[j]) && (ptrl2[j] != NULL))
-	j++;
+        j++;
       if (ptrl2[j] != NULL)
-	{
-	  break;
-	}
+        {
+          break;
+        }
     }
   return ptrl1[i];
 }
@@ -967,7 +1040,7 @@ crawl_down (node * theNode, double tyme)
       otmp = tmp->next;
       tmp = tmp->next->back;
       if (tmp == NULL)
-	return otmp;
+        return otmp;
     }
   return otmp;
 }
