@@ -1,4 +1,4 @@
-/* -----------------------------------------------------     
+/* -----------------------------------------------------
    sighandler.c                         
    handels to following signals:                
    SIGIOT         Input  Output problems             
@@ -16,7 +16,7 @@
    for humans better understandable  (I hope)                       
    -----------------------------------------------------     
    part of the lamarc package                   
-
+ 
    P. Beerli                            
    ----------------------------------------------------- */
 //#include <stdio.h>
@@ -42,6 +42,8 @@
 #endif
 #undef debug
 
+extern int myID;
+
 
 void
 signalhandling (long switcher)
@@ -54,10 +56,12 @@ signalhandling (long switcher)
       signal (SIGBUS, signalhandler);
       signal (SIGUSR1, signalhandler);
 #ifndef SYSTEM_V
+
       signal (SIGXCPU, signalhandler);
       signal (SIGXFSZ, signalhandler);
 #endif
 #endif
+
       signal (SIGFPE, signalhandler);
       signal (SIGSEGV, signalhandler);
       signal (SIGILL, signalhandler);
@@ -70,10 +74,12 @@ signalhandling (long switcher)
       signal (SIGBUS, SIG_DFL);
       signal (SIGUSR1, SIG_DFL);
 #ifndef SYSTEM_V
+
       signal (SIGXCPU, SIG_DFL);
       signal (SIGXFSZ, SIG_DFL);
 #endif
 #endif
+
       signal (SIGFPE, SIG_DFL);
       signal (SIGSEGV, SIG_DFL);
       signal (SIGILL, SIG_DFL);
@@ -90,72 +96,137 @@ signalhandler (int sig)
     {
 #ifndef __MWERKS__
     case SIGIOT:
+#ifdef MPI
+
+      fprintf(stderr, "On node %i happened a", myID);
+#endif
+
       fprintf (stderr, "\nSEVERE ERROR: Input/Output problem!\n");
-      fprintf (stderr, "              Most likely a fatal error in the infile or parmfile\n\n");
-      fprintf (stderr, "              Please report error with as much detail as possible to\n");
+      fprintf (stderr,
+               "              Most likely a fatal error in the infile or parmfile\n\n");
+      fprintf (stderr,
+               "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
     case SIGTRAP:
+#ifdef MPI
+
+      fprintf(stderr, "On node %i happened a", myID);
+#endif
+
       fprintf (stderr, "SEVERE ERROR: Trace trap\n");
-      fprintf (stderr, "              there was an an overflow/underflow/0 divide problem\n");
+      fprintf (stderr,
+               "              there was an an overflow/underflow/0 divide problem\n");
       fprintf (stderr, "              or some other problems.\n");
-      fprintf (stderr, "              But check your infile for errors, too.\n");
-      fprintf (stderr, "              Please report error with as much detail as possible to\n");
+      fprintf (stderr,
+               "              But check your infile for errors, too.\n");
+      fprintf (stderr,
+               "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
     case SIGBUS:
+#ifdef MPI
+
+      fprintf(stderr, "On node %i happened a", myID);
+#endif
+
       fprintf (stderr, "SEVERE ERROR: Bus problems\n");
-      fprintf (stderr, "              this results in an non recoverable crash\n");
-      fprintf (stderr, "              But check your infile for errors, too.\n");
-      fprintf (stderr, "              Please report error with as much detail as possible to\n");
+      fprintf (stderr,
+               "              this results in an non recoverable crash\n");
+      fprintf (stderr,
+               "              But check your infile for errors, too.\n");
+      fprintf (stderr,
+               "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
     case SIGXCPU:
+#ifdef MPI
+
+      fprintf(stderr, "On node %i happened a", myID);
+#endif
+
       fprintf (stderr, "SEVERE ERROR: This program has a time limit?\n");
       fprintf (stderr, "              We didn' program in a time limit,\n");
-      fprintf (stderr, "              report this error to your system administrator, please.\n");
+      fprintf (stderr,
+               "              report this error to your system administrator, please.\n");
       exit (sig);
       break;
     case SIGXFSZ:
+#ifdef MPI
+
+      fprintf(stderr, "On node %i happened a", myID);
+#endif
+
       fprintf (stderr, "SEVERE ERROR: This program has a file size limit?\n");
-      fprintf (stderr, "              We didn't program in a file size limit,\n");
-      fprintf (stderr, "              report this error to your system administrator, please.\n");
+      fprintf (stderr,
+               "              We didn't program in a file size limit,\n");
+      fprintf (stderr,
+               "              report this error to your system administrator, please.\n");
       exit (sig);
       break;
     case SIGUSR1:
-      warning ("\nUser signal received and ignored\n\n");
+#ifdef MPI
+
+      fprintf(stderr, "On node %i happened a USER (?) SIGNAL\n", myID);
+      exit(sig);
+#endif
+      //      warning ("\nUser signal received and ignored\n\n");
       break;
 
 #endif
+
     case SIGFPE:
+#ifdef MPI
+
+      fprintf(stderr, "On node %i happened a", myID);
+#endif
+
       fprintf (stderr, "SEVERE ERROR: Floating point exception\n");
-      fprintf (stderr, "              There was an integer/floating point problem\n");
-      fprintf (stderr, "              Often this is a division by zero. If you dataset is moderately sized\n");
-      fprintf (stderr, "              this is most likely an error in you data (infile).\n");
-      fprintf (stderr, "              Please report error with as much detail as possible to\n");
+      fprintf (stderr,
+               "              There was an integer/floating point problem\n");
+      fprintf (stderr,
+               "              Often this is a division by zero. If you dataset is moderately sized\n");
+      fprintf (stderr,
+               "              this is most likely an error in you data (infile).\n");
+      fprintf (stderr,
+               "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
     case SIGSEGV:
 #ifdef MPI
-      fprintf (stderr, "SEVERE ERROR: Segmentation fault on Node **%i**\n",myID);
+
+      fprintf (stderr, "SEVERE ERROR: Segmentation fault on Node **%i**\n",
+               myID);
 #else
+
       fprintf (stderr, "SEVERE ERROR: Segmentation fault\n");
 #endif
-      fprintf (stderr, "              this results in an non recoverable crash.\n");
-      fprintf (stderr, "              But check the datatype and your infile for errors, too.\n");
-      fprintf (stderr, "              Please report error with as much detail as possible to\n");
+
+      fprintf (stderr,
+               "              this results in an non recoverable crash.\n");
+      fprintf (stderr,
+               "              But check the datatype and your infile for errors, too.\n");
+      fprintf (stderr,
+               "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
     case SIGILL:
+#ifdef MPI
+
+      fprintf(stderr, "On node %i happened a", myID);
+#endif
+
       fprintf (stderr, "SEVERE ERROR: Illegal instruction!\n");
       fprintf (stderr, "              this is maybe a programming error.\n");
-      fprintf (stderr, "              But check your infile for errors, too.\n");
-      fprintf (stderr, "              Please report error with as much detail as possible to\n");
+      fprintf (stderr,
+               "              But check your infile for errors, too.\n");
+      fprintf (stderr,
+               "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
@@ -168,10 +239,12 @@ signalhandler (int sig)
   signal (SIGUSR1, signalhandler);
   signal (SIGBUS, signalhandler);
 #ifndef SYSTEM_V
+
   signal (SIGXCPU, signalhandler);
   signal (SIGXFSZ, signalhandler);
 #endif
 #endif
+
   signal (SIGFPE, signalhandler);
   signal (SIGSEGV, signalhandler);
   signal (SIGILL, signalhandler);
@@ -206,25 +279,26 @@ sig_error (char string[], char filename[], long line)
   exit (-11);
 }
 
-char * myfgets(char *buffer, long bufsize, FILE *infile)
+char *
+myfgets (char *buffer, long bufsize, FILE * infile)
 {
-  long count=0;
-  char ch='\0';
+  long count = 0;
+  char ch = '\0';
   bufsize--;
-  while(!(ch=='\r' || ch=='\n') && count < bufsize)
+  while (!(ch == '\r' || ch == '\n') && count < bufsize)
     {
-      ch = fgetc(infile);
+      ch = fgetc (infile);
       buffer[count] = ch;
       count++;
     }
   //buffer[count]=ch;
-  if(ch=='\r')
-  {
-    ch = fgetc(infile);
-    if (ch!='\n')
-      ungetc(ch,infile);
-  }
-  buffer[count-1]='\0';
+  if (ch == '\r')
+    {
+      ch = fgetc (infile);
+      if (ch != '\n')
+        ungetc (ch, infile);
+    }
+  buffer[count - 1] = '\0';
   return buffer;
 }
 
@@ -244,13 +318,15 @@ malloc_error_found (int value)
       fprintf (stderr, "vm_copy failed\n");
       break;
     case 3:
-      fprintf (stderr, "I tried to reallocate or free space which was already freed\n");
+      fprintf (stderr,
+               "I tried to reallocate or free space which was already freed\n");
       break;
     case 4:
       fprintf (stderr, "Internal memory verification in heap failed\n");
       break;
     case 5:
-      fprintf (stderr, "I tried to reallocate or free space which was never allocated\n");
+      fprintf (stderr,
+               "I tried to reallocate or free space which was never allocated\n");
       break;
     default:
       fprintf (stderr, "huh, what malloc error was this?\n");
@@ -276,7 +352,9 @@ LAMARC_malloc (const unsigned long size, const char file[], const long line)
   x = malloc (size);
   if (x == NULL)
     {
-      fprintf (stderr, "ERROR in memory allocation (malloc(%li)) in file %s on line %li\n", size, file, line);
+      fprintf (stderr,
+               "ERROR in memory allocation (malloc(%li)) in file %s on line %li\n",
+               size, file, line);
       exit (-1);
     }
   return x;
@@ -284,26 +362,32 @@ LAMARC_malloc (const unsigned long size, const char file[], const long line)
 
 
 void *
-LAMARC_calloc (const unsigned long repeats, const unsigned long size, const char file[], const long line)
+LAMARC_calloc (const unsigned long repeats, const unsigned long size,
+               const char file[], const long line)
 {
   void *x;
   x = calloc (repeats, size);
   if (x == NULL)
     {
-      fprintf (stderr, "ERROR in memory allocation (calloc(%li,%li)) in file %s on line %li\n", repeats, size, file, line);
+      fprintf (stderr,
+               "ERROR in memory allocation (calloc(%li,%li)) in file %s on line %li\n",
+               repeats, size, file, line);
       exit (-1);
     }
   return x;
 }
 
 void *
-LAMARC_realloc (void *ptr, const unsigned long size, const char file[], const long line)
+LAMARC_realloc (void *ptr, const unsigned long size, const char file[],
+                const long line)
 {
   void *x;
   x = realloc (ptr, size);
   if (x == NULL)
     {
-      fprintf (stderr, "ERROR in memory allocation (realloc(ptr,%li)) in file %s on lin %li\n", size, file, line);
+      fprintf (stderr,
+               "ERROR in memory allocation (realloc(ptr,%li)) in file %s on lin %li\n",
+               size, file, line);
       exit (-1);
     }
   return x;
@@ -311,4 +395,3 @@ LAMARC_realloc (void *ptr, const unsigned long size, const char file[], const lo
 
 
 #endif /*LAMARC_MALLOC */
-
